==> haskell-system-fileio-0.3.16.7-80.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 system-fileio
version:              0.3.16.7
visibility:           public
id:                   system-fileio-0.3.16.7-LjTTs8ZWIUs5Kgp8YxMRUV
key:                  system-fileio-0.3.16.7-LjTTs8ZWIUs5Kgp8YxMRUV
license:              MIT
maintainer:           https://github.com/fpco/haskell-filesystem
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    Consistent filesystem interaction across GHC versions (deprecated)

description:
    Consistent filesystem interaction across GHC versions (deprecated package).

category:             System
abi:                  79eab9a1c8595bcfed5d48c0820fc250
exposed:              True
exposed-modules:      Filesystem
import-dirs:          /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-system-fileio
hs-libraries:         HSsystem-fileio-0.3.16.7-LjTTs8ZWIUs5Kgp8YxMRUV
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    system-filepath-0.4.14.1-DPifgQZi1apEQ51HShU6I3 text-2.0.2
    time-1.12.2 unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock

haddock-html:         /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-system-fileio-0.3.16.7-81-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 system-fileio
version:              0.3.16.7
visibility:           public
id:                   system-fileio-0.3.16.7-8UKKohiTxeGtYCFRq8OLw
key:                  system-fileio-0.3.16.7-8UKKohiTxeGtYCFRq8OLw
license:              MIT
maintainer:           https://github.com/fpco/haskell-filesystem
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    Consistent filesystem interaction across GHC versions (deprecated)

description:
    Consistent filesystem interaction across GHC versions (deprecated package).

category:             System
abi:                  e50b9f0313fe0e78f8583894f3d67441
exposed:              True
exposed-modules:      Filesystem
import-dirs:          /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-system-fileio
hs-libraries:         HSsystem-fileio-0.3.16.7-8UKKohiTxeGtYCFRq8OLw
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    system-filepath-0.4.14.1-HuIxoRxmfFQmMHeAd2Im text-2.0.2
    time-1.12.2 unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock

haddock-html:         /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
